Module: PlayWhe
- Defined in:
- lib/playwhe.rb,
lib/playwhe/get.rb,
lib/playwhe/http.rb,
lib/playwhe/parser.rb,
lib/playwhe/result.rb,
lib/playwhe/fetcher.rb,
lib/playwhe/version.rb,
lib/playwhe/settings.rb
Defined Under Namespace
Modules: HTTP, Parser, Util Classes: BadResponseError, Error, Fetcher, Get, NetworkError, Result, Settings
Constant Summary collapse
- BIRTHDAY =
Play Whe’s birthday, July 4th, 1994
Date.new(1994, 7, 4)
- THREE_DRAWS_DATE =
The date that Play Whe changed to having 3 draws per day
Date.new(2011, 11, 21)
- FOUR_DRAWS_DATE =
The date that Play Whe changed to having 4 draws per day
Date.new(2015, 7, 6)
- LOWEST_MARK =
The lowest Play Whe mark
1- HIGHEST_MARK =
The highest Play Whe mark
36- SPIRITS =
The spirit name associated with each mark
{ 1 => "centipede", 2 => "old lady", 3 => "carriage", 4 => "dead man", 5 => "parson man", 6 => "belly", 7 => "hog", 8 => "tiger", 9 => "cattle", 10 => "monkey", 11 => "corbeau", 12 => "king", 13 => "crapaud", 14 => "money", 15 => "sick woman", 16 => "jamette", 17 => "pigeon", 18 => "water boat", 19 => "horse", 20 => "dog", 21 => "mouth", 22 => "rat", 23 => "house", 24 => "queen", 25 => "morocoy", 26 => "fowl", 27 => "little snake", 28 => "red fish", 29 => "opium man", 30 => "house cat", 31 => "parson wife", 32 => "shrimps", 33 => "spider", 34 => "blind man", 35 => "big snake", 36 => "donkey" }
- PERIODS =
The short-hand names for the time of day Play Whe results are drawn, ordered by earliest to latest
%w(EM AM AN PM)- DRAW_TIMES =
The times of day, represented as seconds past midnight, that Play Whe results are drawn
{ "EM" => 10 * 3600, # 10:00 AM "AM" => 13 * 3600, # 1:00 PM "AN" => 16 * 3600, # 4:00 PM "PM" => 18 * 3600 + 1800 # 6:30 PM }
- VERSION =
"0.2.0"
Class Method Summary collapse
Class Method Details
.get ⇒ Object
8 9 10 |
# File 'lib/playwhe/get.rb', line 8 def get @_get ||= Get.new(fetcher: fetcher, parser: Parser) end |